==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/c0/c0ffa2d6538973a16a29c079c7b0793d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ChannelBundle/Entity/Channel.php */
class __TwigTemplate_57c9b8b5bdef99587a90e34a51fd0966 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\ChannelBundle\\Entity;

use Doctrine\\DBAL\\Types\\Types;
use Doctrine\\ORM\\Mapping\\ClassMetadata;
use Mautic\\ApiBundle\\Serializer\\Driver\\ApiMetadataDriver;
use Mautic\\CoreBundle\\Doctrine\\Mapping\\ClassMetadataBuilder;
use Mautic\\CoreBundle\\Entity\\CommonEntity;

class Channel extends CommonEntity
{
    /**
     * @var int
     */
    private \$id;

    /**
     * @var string
     */
    private \$channel;

    /**
     * @var int|null
     */
    private \$channelId;

    /**
     * @var string
     */
    private \$channelName;

    /**
     * @var Message
     */
    private \$message;

    /**
     * @var array
     */
    private \$properties = [];

    /**
     * @var bool
     */
    private \$isEnabled = false;

    public static function loadMetadata(ClassMetadata \$metadata): void
    {
        \$builder = new ClassMetadataBuilder(\$metadata);

        \$builder->setTable('message_channels')
                ->addIndex(['channel', 'channel_id'], 'channel_entity_index')
                ->addIndex(['channel', 'is_enabled'], 'channel_enabled_index')
                ->addUniqueConstraint(['message_id', 'channel'], 'channel_index');

        \$builder
            ->addId()
            ->addField('channel', 'string')
            ->addNamedField('channelId', 'integer', 'channel_id', true)
            ->addField('properties', Types::JSON)
            ->createField('isEnabled', 'boolean')
                ->columnName('is_enabled')
                ->build();

        \$builder->createManyToOne('message', Message::class)
                ->addJoinColumn('message_id', 'id', false, false, 'CASCADE')
                ->inversedBy('channels')
                ->build();
    }

    /**
     * Prepares the metadata for API usage.
     */
    public static function loadApiMetadata(ApiMetadataDriver \$metadata): void
    {
        \$metadata->setGroupPrefix('messageChannel')
            ->addListProperties(
                [
                    'id',
                    'channel',
                    'channelId',
                    'channelName',
                    'isEnabled',
                ]
            )
            ->addProperties(
                [
                    'properties',
                    'message',
                ]
            )
            ->build();
    }

    /**
     * @return int
     */
    public function getId()
    {
        return \$this->id;
    }

    /**
     * @return string
     */
    public function getChannel()
    {
        return \$this->channel;
    }

    /**
     * @param string \$channel
     *
     * @return Channel
     */
    public function setChannel(\$channel)
    {
        \$this->channel = \$channel;

        return \$this;
    }

    /**
     * @return int
     */
    public function getChannelId()
    {
        return \$this->channelId;
    }

    /**
     * @param int \$channelId
     *
     * @return Channel
     */
    public function setChannelId(\$channelId)
    {
        if (empty(\$channelId)) {
            \$channelId = null;
        }

        \$this->channelId = \$channelId;

        return \$this;
    }

    /**
     * @return string
     */
    public function getChannelName()
    {
        return \$this->channelName;
    }

    /**
     * @param string \$channelName
     *
     * @return Channel
     */
    public function setChannelName(\$channelName)
    {
        \$this->channelName = \$channelName;

        return \$this;
    }

    /**
     * @return Message
     */
    public function getMessage()
    {
        return \$this->message;
    }

    /**
     * @return Channel
     */
    public function setMessage(Message \$message)
    {
        \$this->message = \$message;

        return \$this;
    }

    /**
     * @return array
     */
    public function getProperties()
    {
        return \$this->properties;
    }

    /**
     * @return Channel
     */
    public function setProperties(array \$properties)
    {
        \$this->properties = \$properties;

        return \$this;
    }

    /**
     * @return bool
     */
    public function isEnabled()
    {
        return \$this->isEnabled;
    }

    /**
     * @param bool \$isEnabled
     *
     * @return Channel
     */
    public function setIsEnabled(\$isEnabled)
    {
        \$this->isEnabled = \$isEnabled;

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ChannelBundle/Entity/Channel.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ChannelBundle/Entity/Channel.php", "/var/www/mautic-ktn/app/bundles/ChannelBundle/Entity/Channel.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/c0/c0ffa2d6538973a16a29c079c7b0793d.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ChannelBundle/Entity/Channel.php */
class __TwigTemplate_57c9b8b5bdef99587a90e34a51fd0966 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\ChannelBundle\\Entity;

use Doctrine\\DBAL\\Types\\Types;
use Doctrine\\ORM\\Mapping\\ClassMetadata;
use Mautic\\ApiBundle\\Serializer\\Driver\\ApiMetadataDriver;
use Mautic\\CoreBundle\\Doctrine\\Mapping\\ClassMetadataBuilder;
use Mautic\\CoreBundle\\Entity\\CommonEntity;

class Channel extends CommonEntity
{
    /**
     * @var int
     */
    private \$id;

    /**
     * @var string
     */
    private \$channel;

    /**
     * @var int|null
     */
    private \$channelId;

    /**
     * @var string
     */
    private \$channelName;

    /**
     * @var Message
     */
    private \$message;

    /**
     * @var array
     */
    private \$properties = [];

    /**
     * @var bool
     */
    private \$isEnabled = false;

    public static function loadMetadata(ClassMetadata \$metadata): void
    {
        \$builder = new ClassMetadataBuilder(\$metadata);

        \$builder->setTable('message_channels')
                ->addIndex(['channel', 'channel_id'], 'channel_entity_index')
                ->addIndex(['channel', 'is_enabled'], 'channel_enabled_index')
                ->addUniqueConstraint(['message_id', 'channel'], 'channel_index');

        \$builder
            ->addId()
            ->addField('channel', 'string')
            ->addNamedField('channelId', 'integer', 'channel_id', true)
            ->addField('properties', Types::JSON)
            ->createField('isEnabled', 'boolean')
                ->columnName('is_enabled')
                ->build();

        \$builder->createManyToOne('message', Message::class)
                ->addJoinColumn('message_id', 'id', false, false, 'CASCADE')
                ->inversedBy('channels')
                ->build();
    }

    /**
     * Prepares the metadata for API usage.
     */
    public static function loadApiMetadata(ApiMetadataDriver \$metadata): void
    {
        \$metadata->setGroupPrefix('messageChannel')
            ->addListProperties(
                [
                    'id',
                    'channel',
                    'channelId',
                    'channelName',
                    'isEnabled',
                ]
            )
            ->addProperties(
                [
                    'properties',
                    'message',
                ]
            )
            ->build();
    }

    /**
     * @return int
     */
    public function getId()
    {
        return \$this->id;
    }

    /**
     * @return string
     */
    public function getChannel()
    {
        return \$this->channel;
    }

    /**
     * @param string \$channel
     *
     * @return Channel
     */
    public function setChannel(\$channel)
    {
        \$this->channel = \$channel;

        return \$this;
    }

    /**
     * @return int
     */
    public function getChannelId()
    {
        return \$this->channelId;
    }

    /**
     * @param int \$channelId
     *
     * @return Channel
     */
    public function setChannelId(\$channelId)
    {
        if (empty(\$channelId)) {
            \$channelId = null;
        }

        \$this->channelId = \$channelId;

        return \$this;
    }

    /**
     * @return string
     */
    public function getChannelName()
    {
        return \$this->channelName;
    }

    /**
     * @param string \$channelName
     *
     * @return Channel
     */
    public function setChannelName(\$channelName)
    {
        \$this->channelName = \$channelName;

        return \$this;
    }

    /**
     * @return Message
     */
    public function getMessage()
    {
        return \$this->message;
    }

    /**
     * @return Channel
     */
    public function setMessage(Message \$message)
    {
        \$this->message = \$message;

        return \$this;
    }

    /**
     * @return array
     */
    public function getProperties()
    {
        return \$this->properties;
    }

    /**
     * @return Channel
     */
    public function setProperties(array \$properties)
    {
        \$this->properties = \$properties;

        return \$this;
    }

    /**
     * @return bool
     */
    public function isEnabled()
    {
        return \$this->isEnabled;
    }

    /**
     * @param bool \$isEnabled
     *
     * @return Channel
     */
    public function setIsEnabled(\$isEnabled)
    {
        \$this->isEnabled = \$isEnabled;

        return \$this;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ChannelBundle/Entity/Channel.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ChannelBundle/Entity/Channel.php", "/var/www/html/mauticGIT-Test/app/bundles/ChannelBundle/Entity/Channel.php");
    }
}
